Enum Priv
#[repr(u8)]pub enum Priv {
Anytime = 0,
Privileged = 1,
}Variants
Anytime = 0
Alarm and SSR underflow configuration and interrupt clear can be written when the APB access is privileged or non-privileged.
Privileged = 1
Alarm and SSR underflow configuration and interrupt clear can be written only when the APB access is privileged.
Implementations